@@ -17,13 +17,6 @@ class PublicationAssetAdmin(admin.ModelAdmin):
 admin.site.register(models.PublicationAsset, PublicationAssetAdmin)
 
 
-class EditorAdmin(admin.ModelAdmin):
-    pass
-
-
-admin.site.register(models.Editor, EditorAdmin)
-
-
 class DesignAdmin(admin.ModelAdmin):
     pass
 
